#
# spec file for package glm
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           glm
Version:        0.9.9.8
Release:        2.12
Summary:        Header only C++ mathematics library for graphics
License:        GPL-2.0-only AND MIT
Group:          Development/Libraries/C and C++
URL:            https://glm.g-truc.net/
#Git-Clone:     https://github.com/g-truc/glm.git
Source:         https://github.com/g-truc/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE glm-0.9.9.8-install.patch
Patch2:         glm-0.9.9.8-install.patch
# PATCH-FIX-OPENSUSE glm-0.9.9.8-pkgconfig.patch add pkgconfig file -- aloisio@gmx.com
Patch3:         glm-0.9.9.8-pkgconfig.patch
# PATCH-FIX-UPSTREAM glm-0.9.9.8-fix_tests_big-endian.patch
Patch4:         glm-0.9.9.8-fix_tests_big-endian.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
OpenGL Mathematics (GLM) is a header only C++ mathematics library for graphics
software based on the OpenGL Shading Language (GLSL) specification.

GLM provides classes and functions designed and implemented with the same naming
conventions and functionalities than GLSL so that when a programmer knows GLSL,
he knows GLM as well which makes it really easy to use.

%package        devel
Summary:        Header only C++ mathematics library for graphics
Group:          Development/Libraries/C and C++
Requires:       cmake

%description    devel
OpenGL Mathematics (GLM) is a header only C++ mathematics library for graphics
software based on the OpenGL Shading Language (GLSL) specification.

GLM provides classes and functions designed and implemented with the same naming
conventions and functionalities than GLSL so that when a programmer knows GLSL,
he knows GLM as well which makes it really easy to use.

%package        doc
Summary:        Documentation for GLM library
Group:          Documentation/Other
BuildArch:      noarch

%description    doc
This package provides the documentation for GLM library.

%prep
%autosetup -p1

%build
%cmake \
  -DCMAKE_CXX_FLAGS="%{optflags} -fPIC -fno-strict-aliasing" \
  -DGLM_TEST_ENABLE=ON
%make_jobs

%install
%cmake_install
%fdupes -s %{buildroot}
%fdupes -s doc/api

%check
%ctest

%files devel
%{_includedir}/glm
%{_libdir}/cmake/%{name}
%{_libdir}/pkgconfig/%{name}.pc

%files doc
# See https://github.com/g-truc/glm/blob/master/manual.md#-licenses for license details
%license readme.md
%doc doc/api
%doc manual.md readme.md

%changelog
* Thu Mar 10 2022 Lubos Kocman <lubos.kocman@suse.com>
- Add back dropped reference for bsc#1135667
* Sat Jun 19 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.9.8
  Features:
  * Added GLM_EXT_vector_intX* and GLM_EXT_vector_uintX*
    extensions
  * Added GLM_EXT_matrix_intX* and GLM_EXT_matrix_uintX*
    extensions
  Improvements:
  * Added clamp, repeat, mirrorClamp and mirrorRepeat function
    to GLM_EXT_scalar_commond and GLM_EXT_vector_commond
    extensions with tests
  Fixes:
  * Fixed unnecessary warnings from matrix_projection.inl
  * Fixed quaternion slerp overload which interpolates with
    extra spins
  * Fixed for glm::length using arch64
  * Fixed singularity check for quatLookAt
  version 0.9.9.7
  Improvements:
  * Improved Neon support with more functions optimized
  * Added CMake GLM interface
  * Added fma implementation based on std::fma
  * Added missing quat constexpr
  * Added GLM_FORCE_QUAT_DATA_WXYZ to store quat data as w,x,y,z
    instead of x,y,z,w
  Fixes:
  * Fixed equal ULP variation when using negative sign
  * Fixed for intersection ray/plane and added related tests
  * Fixed ARM 64bit detection
  * Fixed GLM_EXT_matrix_clip_space warnings
  * Fixed Wimplicit-int-float-conversion warnings with clang 10+
  * Fixed EXT_matrix_clip_space perspectiveFov
  version 0.9.9.6
  Features:
  * Added Neon support to glm
  * Added SYCL support
  * Added EXT_scalar_integer extension with power of two and
    multiple scalar functions
  * Added EXT_vector_integer extension with power of two and
    multiple vector functions
  Improvements:
  * Added missing genType check for bitCount and bitfieldReverse
  Fixes:
  * Fixed for g++6 where -std=c++1z sets __cplusplus to 201500
    instead of 201402
  * Fixed hash hashes qua instead of tquat
  * Fixed .natvis as structs renamed
  * Fixed ldexp and frexp declaration
  * Fixed missing const to quaternion conversion operators
  * Fixed EXT_scalar_ulp and EXT_vector_ulp API coding style
  * Fixed quaternion componant order: w, {x, y, z}
  * Fixed GLM_HAS_CXX11_STL broken on Clang with Linux
  * Fixed Clang or GCC build due to wrong GLM_HAS_IF_CONSTEXPR
    definition
  * Fixed CUDA 9 build
- Drop glm-cmake-config.patch (no longer applies)
- Add glm-0.9.9.8-install.patch (courtesy of Fedora),
  glm-0.9.9.8-pkgconfig.patch and
  glm-0.9.9.8-fix_tests_big-endian.patch
* Mon May 20 2019 Luigi Baldoni <aloisio@gmx.com>
- Added glm-pkgconfig.patch to create glm.pc file
  (fixes bsc#1135667)
* Wed Apr 24 2019 Manfred Hollstein <manfred.h@gmx.net>
- Ensure glmConfig.cmake gets installed:
  * glm-cmake-config.patch
* Sun Apr 14 2019 Sagi <sagiben@gmail.com>
- Update to version 0.9.9.5
  See https://github.com/g-truc/glm/releases/tag/0.9.9.5 for the
    full changelog
  * Fixed build errors when defining GLM_ENABLE_EXPERIMENTAL #884
    [#883]
  * Fixed 'if constexpr' warning #887
  * Fixed missing declarations for frexp and ldexp #886
  changelog can also be found at
  /usr/share/doc/packages/%%{name}-doc/readme.md
* Wed Mar 27 2019 Martin Hauke <mardnh@gmx.de>
- Fix typo in patch glm-cmake-config.patch
- Correct License
* Tue Mar 26 2019 Martin Hauke <mardnh@gmx.de>
- Reenable disabled tests (fixed by upstream)
  * core_func_exponential
  * gtc_packing
  * gtc_integer
  * gtx_common
* Mon Mar 25 2019 Martin Hauke <mardnh@gmx.de>
- Upstream does not package a dedicated LICENSE file.
  Make a note the license terms are included in manual.md
- Use %%fdupes macro also for docs/api/
* Tue Mar 19 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.9.9.4
  See https://github.com/g-truc/glm/releases for the changelog
- Update patch:
  * glm-cmake-config.patch
- Run spec-cleaner
* Wed Jun 29 2016 mpluskal@suse.com
- Update to 0.9.7.5
  * Added Visual C++ Clang toolset detection
  * Fixed uaddCarry warning #497
  * Fixed roundPowerOfTwo and floorPowerOfTwo #503
  * Fixed Visual C++ SIMD instruction set automatic detection in 64
    bits
  * Fixed to_string when used with GLM_FORCE_INLINE #506
  * Fixed GLM_FORCE_INLINE with binary vec4 operators
* Mon Mar 21 2016 dmitry_r@opensuse.org
- Update to version 0.9.7.4
- Fix cmake config location
  * glm-cmake-config.patch
- Drop obsolete
  * glm-0.9.5.3-no_gtc_packing_test.patch
- Drop aliasing.patch, use -fno-strict-aliasing
* Thu Sep 25 2014 schwab@suse.de
- aliasing.patch: fix strict aliasing issues
* Fri May 16 2014 fstrba@suse.com
- Version bump to 0.9.5.3
- Add a patch to disable gtc_packing test that fails on some i586
  systems:
  * glm-0.9.5.3-no_gtc_packing_test.patch
- Add %%fdupes to reduce size
* Mon Mar 24 2014 tchvatal@suse.com
- Version bump to 0.9.5.2:
  * Various bug fixes
  * MIT only license
- Remove no longer needed patch:
  * glm-nonx86.patch
- Use cmake macros to build
* Thu Aug  1 2013 dvaleev@suse.com
- convert sources to UNIX format using dos2unix
- fix build on non x86 architectures (glm-nonx86.patch)
* Thu Jul 18 2013 cfarrell@suse.com
- license update: MIT and GPL-2.0+
  glm-0.9.4.4/test/external/gli/core/shared_ptr.inl is GPL licensed
* Wed Jul 10 2013 dmitry_r@opensuse.org
- Update to version 0.9.4.4
  * Promoted GTC_espilon extension
  * Promoted GTC_ulp extension
  * Removed GLM website from the source repository
  * Added GLM_FORCE_RADIANS so that all functions takes radians for arguments
* Sun Mar  3 2013 jengelh@inai.de
- Add missing BuildRoot directive (resolve SLE build failure)
* Tue Sep  4 2012 adam@mizerski.pl
- update to 0.9.3.4
  - A lot happend since last update.
    Changelog available at http://glm.g-truc.net/
* Sun Feb  5 2012 jengelh@medozas.de
- Remove redundant tags/sections
* Fri Sep 16 2011 adam@mizerski.pl
- update to 0.9.2.4
  - Fixed extensions bugs
* Mon Jun 27 2011 adam@mizerski.pl
- update to 0.9.2.3
  - Fixed build issues
- update to 0.9.2.2
  - Expend matrix constructors flexibility
  - Improved quaternion implementation
  - Fixed many warnings across platforms and compilers
* Thu May 26 2011 adam@mizerski.pl
- update to 0.9.2.1
  - Automatically detect CUDA support
  - Improved compiler detection
  - Fixed errors and warnings in VC with C++ extensions disabled
  - Fixed and tested GLM_GTX_vector_angle
  - Fixed and tested GLM_GTX_rotate_vector
* Sat May 14 2011 adam@mizerski.pl
- new package
